@@ -6,7 +6,7 @@ void Remailer::setUmask()
     size_t umaskValue = 077;
     if (d_arg.option(&umaskOpt, "umask"))
     {
-        umaskValue = stoul(umaskOpt, 0, 8);
+        umaskValue = strToUnsigned(umaskOpt, "umask", 8);
         d_log << level(LOGDEFAULT) << "WARNING: umask setting changed to " <<
             oct << setfill('0') << setw(3) << umaskValue << 
             dec << setfill(' ') << '\n';
